vdoc.exceptions package | vdoc 0.19.0 documentation

Skip to content

# vdoc.exceptions package

## Module contents

Contains all exceptions.

exception vdoc.exceptions.InvalidCredentials

  Bases: `VDocException`

  Exception when the provided credentials are invalid.

exception vdoc.exceptions.InvalidProjectName(name)

  Bases: `VDocException`

  Exception when a requested project name is invalid.

exception vdoc.exceptions.InvalidVersion(version)

  Bases: `VDocException`

  Exception when a requested version has an invalid format.

exception vdoc.exceptions.ProjectNotFound(name)

  Bases: `VDocException`

  Exception when a project doesn’t exist.

exception vdoc.exceptions.ProjectVersionAlreadyExists(name, version)

  Bases: `VDocException`

  Exception when a project version already exist.

exception vdoc.exceptions.ProjectVersionNotFound(name, version)

  Bases: `VDocException`

  Exception when a project version doesn’t exist.

exception vdoc.exceptions.UploadedFileInvalid(reason)

  Bases: `VDocException`

  Exception when the uploaded file is invalid.

exception vdoc.exceptions.VDocException(status_code, detail=None, headers=None)

  Bases: `HTTPException`

  Base exception class for all vdoc exceptions.

vdoc.cli package
vdoc.methods package